@@ -6,8 +6,6 @@ use Mail::ListDetector::Detector::Mailman;
 use Mail::ListDetector::Detector::Ezmlm;
 use Mail::ListDetector::Detector::Smartlist;
 use Mail::ListDetector::Detector::Majordomo;
-use Mail::ListDetector::Detector::RFC2369;
-use Mail::ListDetector::Detector::Listar;
 
 require Exporter;
 use AutoLoader qw(AUTOLOAD);
@@ -33,9 +31,9 @@ use vars qw(@DETECTORS);
 	
 );
 
-$VERSION = '0.012';
+$VERSION = '0.08';
 
-@DETECTORS = qw(Mailman Ezmlm Smartlist RFC2369 Listar Majordomo);
+@DETECTORS = qw(Mailman Ezmlm Smartlist Majordomo);
 
 foreach (@DETECTORS) {
   $_ = "Mail::ListDetector::Detector::" . $_;
@@ -85,11 +83,6 @@ Mail::ListDetector - Perl extension for detecting mailing list messages
 This module analyzses L<Mail:;Internet> objects. It returns a 
 L<Mail::ListDetector::List> object representing the mailing list.
 
-The RFC2369 mailing list detector is also capable of matching some
-Mailman and Ezmlm messages. It is deliberately checked last to allow
-the more specific Mailman and Ezmlm parsing to happen first, and more
-accurately identify the type of mailing list involved.
-
 =head1 METHODS
 
 =head1 new()
@@ -125,12 +118,6 @@ The majordomo and smartlist recognisers don't have much to go on,
 and therefore are probably not as reliable as the other detectors.
 This is liable to be hard to fix.
 
-=item *
-
-Forwarding messages (for example using procmail) can sometimes break
-the C<Sender: > header information needed to recognise some list
-types.
-
 =back
 
 =head1 AUTHOR
